@@ -14,6 +14,10 @@ logger = logging.getLogger(__name__)
 class BaseParser(ABC):
     _registry: dict[str, type["BaseParser"]] = {}
 
+    def __init__(self):
+        # Every instance gets a .name attribute
+        self.name = getattr(self.__class__, "_parser_name", self.__class__.__name__)
+
     def __init_subclass__(cls, name: str | None = None, **kwargs):
         """Automatically register subclasses under a key."""
         super().__init_subclass__(**kwargs)
@@ -57,6 +61,8 @@ class Parser(BaseParser):
             provider_and_model: Literal["llamaparser:"],
             result_type: str,
             mode: bool,
+            preserve_layout_alignment_across_pages: bool,
+            merge_tables_across_pages_in_markdown: bool
     ) -> "LlamaParser": ...
 
     @overload
@@ -154,7 +160,7 @@ class Parser(BaseParser):
         if missing:
             example = ""
             if provider == "llamaparser":
-                example = "Example: Parser('llamaparser:', result_type='md', mode=True)"
+                example = "Example: Parser('llamaparser:', result_type='md', mode=True, extract_tables=True)"
             elif provider == "mistralocr":
                 example = "Example: Parser('mistralocr:ocr-large')"
             elif provider == "huggingface":
@@ -227,11 +233,17 @@ class LangChainParser(BaseParser, name="langchain"):
 
 
 class LlamaParser(BaseParser, name="llamaparser"):
-    def __init__(self, result_type: str, mode: bool, provider_and_model) -> None:
+    def __init__(self, result_type: str,
+                 mode: bool,
+                 provider_and_model: str,
+                 merge_tables_across_pages_in_markdown: bool,
+                 preserve_layout_alignment_across_pages: bool) -> None:
         logging.info("Initializing LlamaParser...")
         self.result_type = result_type
         self.mode = mode
         self.provider_and_model = provider_and_model
+        self.merge_tables_across_pages_in_markdown = merge_tables_across_pages_in_markdown
+        self.preserve_layout_alignment_across_pages = preserve_layout_alignment_across_pages
 
         from llama_parse import LlamaParse, ResultType
         if result_type.lower() in ("md", "markdown"):
@@ -239,7 +251,11 @@ class LlamaParser(BaseParser, name="llamaparser"):
         api_key = os.getenv("LLAMA-PARSER-API-TOKEN")
         if not api_key:
             raise EnvironmentError("Missing LLAMA-PARSER-API-TOKEN in .env file.")
-        self._parser = LlamaParse(api_key=api_key, result_type=result_type, premium_mode=self.mode)
+        self._parser = LlamaParse(api_key=api_key,
+                                  result_type=result_type,
+                                  premium_mode=self.mode,
+                                  merge_tables_across_pages_in_markdown=self.merge_tables_across_pages_in_markdown,
+                                  preserve_layout_alignment_across_pages=self.preserve_layout_alignment_across_pages)
 
     def parse(self, file_path: Path) -> str:
         documents = self._parser.load_data(str(file_path))
